@@ -80,11 +80,7 @@ class MimeNode {
         /**
          * Indicates which encoding should be used for header strings: "Q" or "B"
          */
-        this.textEncoding = (options.textEncoding || '')
-            .toString()
-            .trim()
-            .charAt(0)
-            .toUpperCase();
+        this.textEncoding = (options.textEncoding || '').toString().trim().charAt(0).toUpperCase();
 
         /**
          * Immediate parent for this node (or undefined if not set)
@@ -441,16 +437,10 @@ class MimeNode {
 
     getTransferEncoding() {
         let transferEncoding = false;
-        let contentType = (this.getHeader('Content-Type') || '')
-            .toString()
-            .toLowerCase()
-            .trim();
+        let contentType = (this.getHeader('Content-Type') || '').toString().toLowerCase().trim();
 
         if (this.content) {
-            transferEncoding = (this.getHeader('Content-Transfer-Encoding') || '')
-                .toString()
-                .toLowerCase()
-                .trim();
+            transferEncoding = (this.getHeader('Content-Transfer-Encoding') || '').toString().toLowerCase().trim();
             if (!transferEncoding || !['base64', 'quoted-printable'].includes(transferEncoding)) {
                 if (/^text\//i.test(contentType)) {
                     // If there are no special symbols, no need to modify the text
@@ -540,6 +530,7 @@ class MimeNode {
                     }
                     value = mimeFuncs.buildHeaderValue(structured);
                     break;
+
                 case 'Content-Type':
                     structured = mimeFuncs.parseHeaderValue(value);
 
@@ -564,6 +555,7 @@ class MimeNode {
                         value += '; name=' + param;
                     }
                     break;
+
                 case 'Bcc':
                     if (!this.keepBcc) {
                         // skip BCC values
@@ -1007,7 +999,7 @@ class MimeNode {
             .trim()
             .toLowerCase()
             // use uppercase words, except MIME
-            .replace(/^X-SMTPAPI$|^(MIME|DKIM)\b|^[a-z]|-(SPF|FBL|ID|MD5)$|-[a-z]/gi, c => c.toUpperCase())
+            .replace(/^X-SMTPAPI$|^(MIME|DKIM|ARC|BIMI)\b|^[a-z]|-(SPF|FBL|ID|MD5)$|-[a-z]/gi, c => c.toUpperCase())
             // special case
             .replace(/^Content-Features$/i, 'Content-features');
 
@@ -1023,7 +1015,7 @@ class MimeNode {
     _handleContentType(structured) {
         this.contentType = structured.value.trim().toLowerCase();
 
-        this.multipart = this.contentType.split('/').reduce((prev, value) => (prev === 'multipart' ? value : false));
+        this.multipart = /^multipart\//i.test(this.contentType) ? this.contentType.substr(this.contentType.indexOf('/') + 1) : false;
 
         if (this.multipart) {
             this.boundary = structured.params.boundary = structured.params.boundary || this.boundary || this._generateBoundary();
@@ -1109,6 +1101,11 @@ class MimeNode {
                 value = (value || '').toString().replace(/\r?\n|\r/g, ' ');
                 return this._encodeWords(value);
 
+            case 'Content-Type':
+            case 'Content-Disposition':
+                // if it includes a filename then it is already encoded
+                return (value || '').toString().replace(/\r?\n|\r/g, ' ');
+
             default:
                 value = (value || '').toString().replace(/\r?\n|\r/g, ' ');
                 // encodeWords only encodes if needed, otherwise the original string is returned
