@@ -276,7 +276,7 @@ module.exports.getLogger = (options, defaults) => {
  * @param {Function} reject Function to run if callback ends with an error
  */
 module.exports.callbackPromise = (resolve, reject) =>
-    function() {
+    function () {
         let args = Array.from(arguments);
         let err = args.shift();
         if (err) {
@@ -357,7 +357,7 @@ module.exports.resolveContent = (data, key, callback) => {
 /**
  * Copies properties from source objects to target objects
  */
-module.exports.assign = function(/* target, ... sources */) {
+module.exports.assign = function (/* target, ... sources */) {
     let args = Array.from(arguments);
     let target = args.shift() || {};
 
@@ -489,15 +489,7 @@ function createDefaultLogger(levels) {
 
         message = util.format(message, ...args);
         message.split(/\r?\n/).forEach(line => {
-            console.log(
-                '[%s] %s %s',
-                new Date()
-                    .toISOString()
-                    .substr(0, 19)
-                    .replace(/T/, ' '),
-                levelNames.get(level),
-                prefix + line
-            );
+            console.log('[%s] %s %s', new Date().toISOString().substr(0, 19).replace(/T/, ' '), levelNames.get(level), prefix + line);
         });
     };
 
